@@ -9,8 +9,11 @@
  *
  */
 
+#pragma once
+
 #include <getopt.h>
 #include <libmemcached/memcached.h>
+#include "libmemcached/watchpoint.h"
 #include "client_options.h"
 
 #if TIME_WITH_SYS_TIME
@@ -40,6 +43,10 @@ struct memcached_programs_help_st
   char *not_used_yet;
 };
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 char *strdup_cleanup(const char *str);
 void cleanup(void);
 long int timedif(struct timeval a, struct timeval b);
@@ -50,3 +57,8 @@ void help_command(const char *command_name, const char *description,
 void process_hash_option(memcached_st *memc, char *opt_hash);
 bool initialize_sasl(memcached_st *memc, char *user, char *password);
 void shutdown_sasl(void);
+void initialize_sockets(void);
+
+#ifdef __cplusplus
+} // extern "C"
+#endif
