@@ -6,10 +6,9 @@
  * the COPYING file in the parent directory for full text.
  */
 
-#ifndef HASHKIT_COMMON_H
-#define HASHKIT_COMMON_H
+#pragma once
 
-#include "config.h"
+#include <config.h>
 
 #include <assert.h>
 #include <errno.h>
@@ -17,7 +16,7 @@
 #include <stdlib.h>
 #include <math.h>
 
-#include "hashkit.h"
+#include <libhashkit/hashkit.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -32,5 +31,3 @@ int update_continuum(hashkit_st *hashkit);
 #ifdef __cplusplus
 }
 #endif
-
-#endif /* HASHKIT_COMMON_H */
